import WooCommerceRestApi from '@woocommerce/woocommerce-rest-api';
import dotenv from 'dotenv';
import fs from 'fs';

dotenv.config();

const api = new WooCommerceRestApi({
  url: process.env.WC_STORE_URL,
  consumerKey: process.env.WC_CONSUMER_KEY,
  consumerSecret: process.env.WC_CONSUMER_SECRET,
  version: 'wc/v3'
});

async function scrapeProducts() {
  try {
    const response = await api.get('products', {
      per_page: 100, // Adjust based on your needs
      page: 1
    });

    const products = response.data.map(product => ({
      id: product.id,
      name: product.name,
      price: product.price,
      regular_price: product.regular_price,
      sale_price: product.sale_price,
      description: product.description,
      short_description: product.short_description,
      categories: product.categories.map(cat => cat.name),
      images: product.images.map(img => img.src),
      sku: product.sku,
      stock_status: product.stock_status,
      stock_quantity: product.stock_quantity
    }));

    // Save to JSON file
    fs.writeFileSync('products.json', JSON.stringify(products, null, 2));
    console.log(`Successfully scraped ${products.length} products`);
    console.log('Data saved to products.json');

  } catch (error) {
    console.error('Error scraping products:', error.message);
  }
}

scrapeProducts();