import express from 'express';
import { Question } from '../models/Question.js';
import { auth } from '../middleware/auth.js';

const router = express.Router();

// Get all questions
router.get('/', auth, async (req, res) => {
  try {
    const questions = await Question.find();
    res.json(questions);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

// Add a new question
router.post('/', auth, async (req, res) => {
  const question = new Question({
    text: req.body.text,
    options: req.body.options,
    category: req.body.category,
    difficulty: req.body.difficulty,
    explanation: req.body.explanation
  });

  try {
    const newQuestion = await question.save();
    res.status(201).json(newQuestion);
  } catch (error) {
    res.status(400).json({ message: error.message });
  }
});

export default router;