import express from 'express';
import { Quiz } from '../models/Quiz.js';
import { auth } from '../middleware/auth.js';

const router = express.Router();

// Get all quizzes
router.get('/', auth, async (req, res) => {
  try {
    const quizzes = await Quiz.find().populate('questions');
    res.json(quizzes);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

// Create a new quiz
router.post('/', auth, async (req, res) => {
  const quiz = new Quiz({
    title: req.body.title,
    description: req.body.description,
    questions: req.body.questions,
    category: req.body.category,
    timeLimit: req.body.timeLimit,
    passingScore: req.body.passingScore
  });

  try {
    const newQuiz = await quiz.save();
    res.status(201).json(newQuiz);
  } catch (error) {
    res.status(400).json({ message: error.message });
  }
});

// Submit quiz attempt
router.post('/:id/submit', auth, async (req, res) => {
  try {
    const quiz = await Quiz.findById(req.params.id).populate('questions');
    const answers = req.body.answers;
    let score = 0;

    answers.forEach(answer => {
      const question = quiz.questions.find(q => q._id.toString() === answer.questionId);
      if (question && question.options[answer.selectedOption].isCorrect) {
        score++;
      }
    });

    const finalScore = (score / quiz.questions.length) * 100;

    // Update user's quiz attempts
    req.user.quizAttempts.push({
      quiz: quiz._id,
      score: finalScore,
      completedAt: new Date()
    });
    await req.user.save();

    res.json({ score: finalScore, passed: finalScore >= quiz.passingScore });
  } catch (error) {
    res.status(400).json({ message: error.message });
  }
});

export default router;